@@ -2,26 +2,26 @@ import numpy as np
 import pandas as pd
 from matplotlib import pyplot as plt
 from matplotlib.colors import rgb2hex
-import drawSvg as draw
+import svgwrite
 from visuEL.Sampler import CminSampler
 
 class Vis:
     width_in_block = 20
-    padding = 1
+    padding = 5
     square_s = 50
 
-    def __init__(self, mapping_name=None, legend=True, max_n_color=6):
+    def __init__(self, mapping_name=None, legend=True, max_n_color=6, max_seq=10000):
         self.mapping_name = mapping_name
         self.legend = legend
         self.max_n_color = int(max_n_color)
         self.svg = None
-        self.activities_df = None
+        self.activities = None
+        self.max_seq = max_seq
 
     def _load(self, variants):
         sampler = CminSampler(variants, 0)
-        sampling = sampler.sample()
-        print (sampling)
-        self.activities_df = self.activity_definition(sampling)
+        sampling = sampler.sample(max_seq=self.max_seq)
+        self.activities = self.activity_definition(sampling)
         self.svg = self._build_svg(sampling)
 
 
@@ -45,7 +45,7 @@ class Vis:
 
         # Assign color
         n_color = min(self.max_n_color, y.shape[0])
-        palette = plt.get_cmap('magma', n_color)
+        palette = plt.get_cmap('magma', n_color+1)
         colors = [rgb2hex(palette(x)) for x in range(n_color)]
         y['color'] = colors[-1]
         y.loc[y.iloc[0:n_color].index, 'color'] = colors
@@ -61,56 +61,56 @@ class Vis:
         y['name'] = y['name'].map(mapping)
         y['ranking'] = np.arange(y.shape[0])
 
-        y.loc[y.iloc[n_color-1:].index, 'name'] = '{} hidden...'.format(y.shape[0]-n_color+1)
-        y = y.to_dict(orient='index')
-
-        return y
+        if y.shape[0] > self.max_n_color:
+            y.loc[y.iloc[n_color-1:].index, 'name'] = '+ {} others...'.format(y.shape[0]-n_color+1)
+            y.loc[y.iloc[n_color-1:].index, 'color'] = '#eee'
+        return y.to_dict(orient='index')
 
     def _build_svg(self, sampling):
         n = len(sampling)
         if self.legend:
-            n += min(self.max_n_color, len(self.activities_df))+3
+            n += min(self.max_n_color, len(self.activities)) + 2
 
         height = n*(self.padding+self.square_s)
         width = self.width_in_block * self.square_s
 
-        d = draw.Drawing(width, height, origin=(0,0), displayInline=False)
+        d = svgwrite.Drawing('test.svg', profile='tiny', size=(width, height))
         for row, trace in enumerate(sampling):
             for col, activity in enumerate(trace):
-                top = height - (((row+1)*self.square_s) + ((row+1)*self.padding+1))
+                top = (((row)*self.square_s) + ((row)*self.padding+1))
                 if len(trace) > self.width_in_block:
                     if col == len(trace) - 2:
                         left = (self.width_in_block - 2)*self.square_s
                         r = self.square_s/15
-                        d.append(draw.Circle(left+(self.square_s/2), top+(self.square_s/2), r, fill='#000000'))
-                        d.append(draw.Circle(left+(self.square_s/2)-(r*3), top+(self.square_s/2), r, fill='#000000'))
-                        d.append(draw.Circle(left+(self.square_s/2)+(r*3), top+(self.square_s/2), r, fill='#000000'))
+                        d.add(d.circle((left+(self.square_s/2), top+(self.square_s/2)), r, fill='#000000'))
+                        d.add(d.circle((left+(self.square_s/2)-(r*3), top+(self.square_s/2)), r, fill='#000000'))
+                        d.add(d.circle((left+(self.square_s/2)+(r*3), top+(self.square_s/2)), r, fill='#000000'))
                         continue
                     if col == len(trace)-1:
                         left = (self.width_in_block - 1)*self.square_s
-                        d.append(draw.Rectangle(left, top, self.square_s, self.square_s, fill=self.activities_df[trace[-1]]['color']))
+                        d.add(d.rect((left, top), (self.square_s, self.square_s), fill=self.activities[trace[-1]]['color']))
                         continue
                     if col > self.width_in_block - 3:
                         continue
                 left = col*self.square_s
-                d.append(draw.Rectangle(left, top, self.square_s, self.square_s, fill=self.activities_df[activity]['color']))
+                d.add(d.rect((left, top), (self.square_s, self.square_s), fill=self.activities[activity]['color']))
         if self.legend:
 
             font_size = self.square_s*0.6
-            t = (top - ((self.square_s + self.padding)*2))
-            d.append(draw.Text('LEGEND (top activities)', font_size, 0, t+(self.square_s*0.2), fill='black'))
+            #d.add(d.Text('LEGEND (top activities)', font_size, 0, t+(self.square_s*0.2), fill='black'))
 
-            for i, v in enumerate(self.activities_df.values()):
+            for i, v in enumerate(self.activities.values()):
                 if v['ranking']>=self.max_n_color:
                     continue
-                t = (top - ((self.square_s + self.padding)*(v['ranking']+3)))
-                d.append(draw.Rectangle(0, t, self.square_s*0.8, self.square_s*0.8, fill=v['color']))
-                d.append(draw.Text(v['name'], font_size, self.square_s, t+(self.square_s/5), fill='black'))
-
+                t = (top + ((self.square_s + self.padding)*(v['ranking']+2)))
+                d.add(d.rect((0, t), (self.square_s*0.8, self.square_s*0.8), fill=v['color']))
+                d.add(d.text(v['name'],  insert=(self.square_s, t+(self.square_s*0.6)), fill='black', font_size=font_size,))
+        d.viewbox(0, 0, width, height)
+        d.fit(horiz='left', vert='top', scale='meet')
         return d
 
     def get_svg(self):
-        return self.svg.asSvg()
+        return self.svg.tostring()
 
     def save_svg(self,filename, folder=''):
-        self.svg.saveSvg('{}{}.svg'.format(folder, filename))
\ No newline at end of file
+        self.svg.save('{}{}.svg'.format(folder, filename))
\ No newline at end of file
